```bash
usage: maker.py [-h] -i INPUT_PATH [-d DURATION_INTERVAL_SECOND] [-rw MAX_ROW_WIDTH]

options:
  -h, --help            show this help message and exit
  -i INPUT_PATH, --input-path INPUT_PATH
                        The path of input files or the directory that keeps the inputs.
  -d DURATION_INTERVAL_SECOND, --duration-interval-second DURATION_INTERVAL_SECOND
                        The interval that partition the video.
  -rw MAX_ROW_WIDTH, --max-row-width MAX_ROW_WIDTH
                        The width of each row.
```
